==> lxqt-config_0.16.1.orig.tar.xz: lxqt-config-0.16.1/liblxqt-config-cursor/translations/lxqt-config-cursor_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt saguaren gaiaren konfigurazioa</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Aukeratu erabili nahi duzun kurtsorearen gaia (aurrebista pasatzailea kurtsorea probatzeko). &lt;b&gt; 1LXQt saioak aldaketa honen ondoren berrabiarazi behar ditu &lt;/b&gt; 2:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalatu gai berria...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Kendu gaia</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="233"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme errorea</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="234"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Ezin duzu gai aktiboa kendu!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>inprimakia</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt-k ezin izan du kurtsorerik aurkitu. Horren ordez X11 kurtsorearen gaia lehenetsiko da. LXQt-ek direktorio hauek begiratu ditu:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Erakutsi ...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Deskribapena</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.17.1.orig.tar.xz: lxqt-config-0.17.1/liblxqt-config-cursor/translations/lxqt-config-cursor_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt saguaren gaiaren konfigurazioa</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Aukeratu erabili nahi duzun kurtsorearen gaia (aurrebista pasatzailea kurtsorea probatzeko). &lt;b&gt; 1LXQt saioak aldaketa honen ondoren berrabiarazi behar ditu &lt;/b&gt; 2:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalatu gai berria...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>LXQt saioa berrabiarazi behar da aldaketa hau ikusteko.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Kendu gaia</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation>Tamaina</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="233"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme errorea</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="234"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Ezin duzu gai aktiboa kendu!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>inprimakia</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt-k ezin izan du kurtsorerik aurkitu. Horren ordez X11 kurtsorearen gaia lehenetsiko da. LXQt-ek direktorio hauek begiratu ditu:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Erakutsi ...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Izena</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Deskribapena</translation>
    </message>
</context>
</TS>
